==> krename_3.0.3.orig.tar.gz: krename-3.0.3/krename/tabs.h <==
/***************************************************************************
                          tabs.h  -  description
                             -------------------
    begin                : Die Mai 20 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABS_H
#define TABS_H

#include <qwidget.h>
#include <qdialog.h>

class KMenuBar;
class KRenameImpl;
class KPushButton;
class QCloseEvent;
class QRect;
class QString;
class QTabWidget;
class tabs : public QDialog  {
    Q_OBJECT
    public: 
        tabs(KRenameImpl* impl, QRect r, QWidget *parent=0, const char *name=0);
        ~tabs();

        KRenameImpl* getKRename() { return krename; }

    private slots:
        void slotAddPage( QWidget* page, const QString & title );
        void slotShowPage( int page );
        void slotEnableFinish( bool b );        
    
    protected:
        virtual void keyPressEvent( QKeyEvent *e );
        
    protected:
        KRenameImpl* krename;
        KPushButton* finishButton;
        KPushButton* cancelButton;

        KMenuBar* menuBar;
        QTabWidget* tab;
};

#endif

==> krename_3.0.14.orig.tar.gz: krename-3.0.14/krename/tabs.h <==
/***************************************************************************
                          tabs.h  -  description
                             -------------------
    begin                : Die Mai 20 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABS_H
#define TABS_H

#include <qwidget.h>
#include <qdialog.h>

class KMenuBar;
class KRenameImpl;
class KPushButton;
class QCloseEvent;
class QRect;
class QString;
class QTabWidget;
class tabs : public QDialog  {
    Q_OBJECT
    public: 
        tabs(KRenameImpl* impl, QRect r, QWidget *parent=0, const char *name=0);
        ~tabs();

        inline KRenameImpl* getKRename() { return krename; }

    private slots:
        void slotAddPage( QWidget* page, const QString & title );
        void slotShowPage( int page );
        void slotEnableFinish( bool b );        
        void slotTabChanged();

    protected:
        virtual void keyPressEvent( QKeyEvent *e );
        
    protected:
        KRenameImpl* krename;
        KPushButton* finishButton;
        KPushButton* cancelButton;

        KMenuBar* menuBar;
        QTabWidget* tab;
};

#endif
